<?php
/*
Plugin Name: Flayr Player for FlatPress
Version: 1.0
Plugin URI: http://www.azett.com
Description: Flash video player for displaying a bunch of different video formats including FLV, F4V, MP4 (including H.264). See <a href="http://www.flayr.net/">flayr.net</a> for details!
Author: Adapted to FlatPress by azett
Author URI: http://www.azett.com
*/

/*

Usage example:
--------------
[flayr="images/movie.mp4" width="384" height="288" skin="black" preview="images/preview.jpg"]

Attributes:
-----------
Default attribute ("flayr=..."):    path to movie file (mandatory, of course)
width (optional):                   player's width
height (optional):                  player's height
skin (optional):                    player's skin (see fp-plugins/flayrplayer/skins or edit fp-plugins/flayrplayer/skin.psd to your needs)
preview (optional):                 path to the preview image shown before playing the video

CSS selectors:
--------------
Flayr swf object itself:            object.flayrplayer_object
swf object is wrapped in:           div.flayrplayer_div

*/
 
// this will tell FlatPress to load the new tags at the very beginning 
 
add_filter('init', 'plugin_flayrplayer_tags');
 
// Injecting the Flayr tag into FP's syntax
function plugin_flayrplayer_tags() {
        $bbcode = plugin_bbcode_init(); //import the "global" bbcode object into current function
                                         // this way 
                                         // a) parsing is done only once, and by the official plugin
                                         // b) you create only ONE object, and therefore computation is quicker
        $bbcode->addCode (
                    'flayr',  // tag name: this will go between square brackets
                    'callback_replace_single', // type of action: we'll use a callback function
                    'plugin_flayrplayer_flayr', // name of the callback function
                    array('usecontent_param' => array ('default')), // supported parameters: "default" is [acronym=valore]
                    'inline', // type of the tag, inline or block, etc
                    array ('listitem', 'block', 'inline', 'link'), // type of elements in which you can use this tag
                    array ()  // type of elements where this tag CAN'T go (in this case, none, so it can go everywhere)
        );
 
        $bbcode->setCodeFlag ('flayr', 'closetag', BBCODE_CLOSETAG_FORBIDDEN); // a closing tag is forbidden (no [/tag])
 
}
 
// $content is the text between the two tags, i.e. [tag]CONTAINED TEXT[/tag] $content='CONTAINED TEXT'
// $attributes is an associative array where keys are the tag properties. default is the [tagname=value] property
 
function plugin_flayrplayer_flayr($action, $attr, $content, $params, $node_object) { 
    if ($action == 'validate') {
        // not used for now
        return true;
    }

    // Check tag params (default values will be used for those not set)
    $movie = BLOG_BASEURL."fp-content/".$attr['default']; // obviously, here's no default value ;)
    $width = isset($attr['width']) && $attr['width'] != "" ? $attr['width'] : "384";
    $height = isset($attr['height']) && $attr['height'] != "" ? $attr['height'] : "288";
    $skin = isset($attr['skin']) && $attr['skin'] != "" ? $attr['skin'] : "glass";
    $preview = isset($attr['preview']) && $attr['preview'] != "" ? BLOG_BASEURL."fp-content/".$attr['preview'] : "";
    // Feel free to add more parameters. See fp-plugins/flayrplayer/readme.txt for the detailed documentation of Flayr's available parameters.

    $pdir = plugin_geturl('flayrplayer');
    $player = "{$pdir}flayr.swf";
    $dataStr = "{$player}?movie={$movie}&amp;controls=show&amp;preview={$preview}&amp;buffer=false&amp;theme={$pdir}skins/{$skin}.png";
    
    $html  = '<div class="flayrplayer_div">';
    $html .= '<object class="flayrplayer_object" type="application/x-shockwave-flash" data="'.$dataStr.'" width="'.$width.'" height="'.$height.'">';
    $html .= '  <param name="movie" value="'.$dataStr.'" />';
    $html .= '  <param name="allowscriptaccess" value="always" />';
    $html .= '  <param name="allowfullscreen" value="true" />';
    $html .= '  Flash missing. <a href="'.$movie.'">Download '.$attr['default'].'</a>';
    $html .= '</object></div>';

    return $html;
}
